==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYTYPEPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour NONCONFORMITYTYPEPARTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYTYPEPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYTYPEPARTID_Type", propOrder = {
    "nonconformitytypeid",
    "partid"
})
public class NONCONFORMITYTYPEPARTID_Type {

    @XmlElement(name = "NONCONFORMITYTYPEID", required = true)
    protected NONCONFORMITYTYPEID_Type nonconformitytypeid;
    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;

    /**
     * Obtient la valeur de la propriété nonconformitytypeid.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public NONCONFORMITYTYPEID_Type getNONCONFORMITYTYPEID() {
        return nonconformitytypeid;
    }

    /**
     * Définit la valeur de la propriété nonconformitytypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public void setNONCONFORMITYTYPEID(NONCONFORMITYTYPEID_Type value) {
        this.nonconformitytypeid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYTYPEPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for NONCONFORMITYTYPEPARTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYTYPEPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYTYPEPARTID_Type", propOrder = {
    "nonconformitytypeid",
    "partid"
})
public class NONCONFORMITYTYPEPARTID_Type {

    @XmlElement(name = "NONCONFORMITYTYPEID", required = true)
    protected NONCONFORMITYTYPEID_Type nonconformitytypeid;
    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;

    /**
     * Gets the value of the nonconformitytypeid property.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public NONCONFORMITYTYPEID_Type getNONCONFORMITYTYPEID() {
        return nonconformitytypeid;
    }

    /**
     * Sets the value of the nonconformitytypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public void setNONCONFORMITYTYPEID(NONCONFORMITYTYPEID_Type value) {
        this.nonconformitytypeid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

}
